==> haskell-bytes-0.17.2-57-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bytes
version:              0.17.2
visibility:           public
id:                   bytes-0.17.2-E17yjnmHvPaKt10tkTBslW
key:                  bytes-0.17.2-E17yjnmHvPaKt10tkTBslW
license:              BSD-3-Clause
copyright:            Copyright (C) 2013-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             https://github.com/ekmett/bytes
synopsis:             Sharing code for serialization between binary and cereal
description:          Sharing code for serialization between binary and cereal.
category:             Data, Serialization
abi:                  4087b42e1b435194b35204323e92470f
exposed:              True
exposed-modules:
    Data.Bytes.Get Data.Bytes.Put Data.Bytes.Serial Data.Bytes.Signed
    Data.Bytes.VarInt

import-dirs:          /usr/lib/ghc-9.0.2/site-local/bytes-0.17.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/bytes-0.17.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytes
hs-libraries:         HSbytes-0.17.2-E17yjnmHvPaKt10tkTBslW
depends:
    base-4.15.1.0 binary-0.8.8.0
    binary-orphans-1.0.4-5fNKowuqpXoBKm49QTp9b5 bytestring-0.10.12.1
    cereal-0.5.8.3-KCibhvvTsuv86wVgcPkD6 containers-0.6.4.1
    hashable-1.4.2.0-8JSq7I7AhyyZ2Q90BxZWW mtl-2.2.2
    scientific-0.3.7.0-6CvCEFxXBWR5nYRp7k6pyR text-1.2.5.0 time-1.9.3
    transformers-0.5.6.2
    transformers-compat-0.7.2-ZzSHjvD4flB2ChCq5TVbH
    unordered-containers-0.2.19.1-Km0aDxhChoIJJSbiufyazz
    void-0.7.3-BXIeD8PDyVa6FzS0UDPl2

haddock-interfaces:   /usr/share/doc/haskell-bytes/html/bytes.haddock
haddock-html:         /usr/share/doc/haskell-bytes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytes-0.17.2-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bytes
version:              0.17.2
visibility:           public
id:                   bytes-0.17.2-4cJuXoHYYowHCfJ8g4UKJ7
key:                  bytes-0.17.2-4cJuXoHYYowHCfJ8g4UKJ7
license:              BSD-3-Clause
copyright:            Copyright (C) 2013-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             https://github.com/ekmett/bytes
synopsis:             Sharing code for serialization between binary and cereal
description:          Sharing code for serialization between binary and cereal.
category:             Data, Serialization
abi:                  31125902df6f974c678b1b62099fabb4
exposed:              True
exposed-modules:
    Data.Bytes.Get Data.Bytes.Put Data.Bytes.Serial Data.Bytes.Signed
    Data.Bytes.VarInt

import-dirs:          /usr/lib/ghc-9.0.2/site-local/bytes-0.17.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/bytes-0.17.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytes
hs-libraries:         HSbytes-0.17.2-4cJuXoHYYowHCfJ8g4UKJ7
depends:
    base-4.15.1.0 binary-0.8.8.0
    binary-orphans-1.0.4.1-BCVDIKXbZTC4gUBdEWFvV bytestring-0.10.12.1
    cereal-0.5.8.3-KCibhvvTsuv86wVgcPkD6 containers-0.6.4.1
    hashable-1.4.2.0-8EyZ5q0qf6V2oPuIX4Sz4t mtl-2.2.2
    scientific-0.3.7.0-AejKlNxs4tarEm4tm38IP text-1.2.5.0 time-1.9.3
    transformers-0.5.6.2
    transformers-compat-0.7.2-ZzSHjvD4flB2ChCq5TVbH
    unordered-containers-0.2.19.1-4LWMSZiig8M6j2saT8CDNm
    void-0.7.3-BXIeD8PDyVa6FzS0UDPl2

haddock-interfaces:   /usr/share/doc/haskell-bytes/html/bytes.haddock
haddock-html:         /usr/share/doc/haskell-bytes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
